@@ -51,20 +51,25 @@ private Q_SLOTS:
             { "test.jpg",                      "image/jpeg"},
             { "test.jxl",                      "image/jxl"},
             { "test_libreoffice.docx",         "application/vnd.openxmlformats-officedocument.wordprocessingml.document"},
+            { "test_libreoffice.pptx",         "application/vnd.openxmlformats-officedocument.presentationml.presentation"},
+            { "test_libreoffice.xlsx",         "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet"},
             { "test.m4a",                      "audio/mp4"},
             { "test_missing_content.odt",      "application/vnd.oasis.opendocument.text"},
             { "test_missing_meta.odt",         "application/vnd.oasis.opendocument.text"},
             { "test.mkv",                      "video/x-matroska"},
             { "test.mp3",                      "audio/mpeg"},
+            { "test.id3v1.mp3",                "audio/mpeg"},
             { "test.mpc",                      "audio/x-musepack"},
             { "test_no_gps.jpg",               "image/jpeg"},
             { "test.odg",                      "application/vnd.oasis.opendocument.graphics"},
             { "test.odp",                      "application/vnd.oasis.opendocument.presentation"},
             { "test.odt",                      "application/vnd.oasis.opendocument.text"},
+            { "test.ods",                      "application/vnd.oasis.opendocument.spreadsheet"},
             { "test.fodg",                     "application/vnd.oasis.opendocument.graphics-flat-xml"},
             { "test.fodp",                     "application/vnd.oasis.opendocument.presentation-flat-xml"},
             { "test.fodt",                     "application/vnd.oasis.opendocument.text-flat-xml"},
             { "test.ogg",                      "audio/x-vorbis+ogg"},
+            { "test.flac.ogg",                 "audio/x-flac+ogg"},
             { "test.mml",                      "application/mathml+xml"},
             { "test_multivalue.ogg",           "audio/x-vorbis+ogg"},
             { "test.ogv",                      "video/x-theora+ogg"},
@@ -80,6 +85,7 @@ private Q_SLOTS:
             { "test.wav",                      "audio/vnd.wave"},
             { "test.wav",                      "audio/x-wav"},
             { "test.webm",                     "video/webm"},
+            { "test.webp",                     "image/webp"},
             { "test_dcterms.svg",              "image/svg+xml"},
             { "test_with_container.svg",       "image/svg+xml"},
             { "test_with_metadata.svg",        "image/svg+xml"},
@@ -139,6 +145,8 @@ private Q_SLOTS:
         }
         if (fileMime.name() != mimeType) {
             const auto aliases = fileMime.aliases();
+	    if (!aliases.contains(mimeType))
+		QCOMPARE(fileMime.name(), mimeType);
             QVERIFY(aliases.contains(mimeType));
         }
     }
